@@ -1,6 +1,11 @@
 import typing
+
 from typing_extensions import Literal
-from .base_category import BaseCategory
+from vkbottle_types.responses.base import (
+    BaseGetUploadServerResponse,
+    BaseUploadServer,
+    OkResponse,
+)
 from vkbottle_types.responses.docs import (
     AddResponse,
     DocsDoc,
@@ -15,11 +20,8 @@ from vkbottle_types.responses.docs import (
     SearchResponse,
     SearchResponseModel,
 )
-from vkbottle_types.responses.base import (
-    BaseUploadServer,
-    GetUploadServerResponse,
-    OkResponse,
-)
+
+from .base_category import BaseCategory
 
 
 class DocsCategory(BaseCategory):
@@ -129,7 +131,7 @@ class DocsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("docs.getMessagesUploadServer", params)
-        model = GetUploadServerResponse
+        model = BaseGetUploadServerResponse
         return model(**response).response
 
     async def get_types(self, owner_id: int, **kwargs) -> GetTypesResponseModel:
@@ -166,7 +168,7 @@ class DocsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("docs.getWallUploadServer", params)
-        model = GetUploadServerResponse
+        model = BaseGetUploadServerResponse
         return model(**response).response
 
     async def save(
