@@ -1,6 +1,7 @@
 import typing
+
 from typing_extensions import Literal
-from .base_category import BaseCategory
+from vkbottle_types.responses.base import OkResponse
 from vkbottle_types.responses.users import (
     GetFollowersFieldsResponse,
     GetFollowersFieldsResponseModel,
@@ -15,7 +16,8 @@ from vkbottle_types.responses.users import (
     SearchResponseModel,
     UsersUserFull,
 )
-from vkbottle_types.responses.base import OkResponse
+
+from .base_category import BaseCategory
 
 
 class UsersCategory(BaseCategory):
@@ -70,7 +72,7 @@ class UsersCategory(BaseCategory):
         fields=None,
         name_case=None,
         **kwargs
-    ) -> GetFollowersResponseModel:
+    ) -> typing.Union[GetFollowersResponseModel, GetFollowersFieldsResponseModel]:
         """Returns a list of IDs of followers of the user in question, sorted by date added, most recent first.
 
         :param user_id: User ID.
@@ -121,7 +123,9 @@ class UsersCategory(BaseCategory):
         count=None,
         fields=None,
         **kwargs
-    ) -> GetSubscriptionsResponseModel:
+    ) -> typing.Union[
+        GetSubscriptionsResponseModel, GetSubscriptionsExtendedResponseModel
+    ]:
         """Returns a list of IDs of users and communities followed by the user.
 
         :param user_id: User ID.
