@@ -1,41 +1,52 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import (
     SecureGiveEventStickerItem,
     SecureLevel,
+    SecureSetCounterItem,
     SecureSmsNotification,
     SecureTokenChecked,
     SecureTransaction,
 )
 
+from .base_response import BaseResponse
+
 
 class CheckTokenResponse(BaseResponse):
-    response: SecureTokenChecked = None
+    response: SecureTokenChecked
 
 
 class GetAppBalanceResponse(BaseResponse):
-    response: int = None
+    response: int
 
 
 class GetSMSHistoryResponse(BaseResponse):
-    response: typing.List["SecureSmsNotification"] = None
+    response: typing.List["SecureSmsNotification"]
 
 
 class GetTransactionsHistoryResponse(BaseResponse):
-    response: typing.List["SecureTransaction"] = None
+    response: typing.List["SecureTransaction"]
 
 
 class GetUserLevelResponse(BaseResponse):
-    response: typing.List["SecureLevel"] = None
+    response: typing.List["SecureLevel"]
 
 
 class GiveEventStickerResponse(BaseResponse):
-    response: typing.List["SecureGiveEventStickerItem"] = None
+    response: typing.List["SecureGiveEventStickerItem"]
 
 
 class SendNotificationResponse(BaseResponse):
-    response: typing.List[int] = None
+    response: typing.List[int]
+
+
+class SetCounterArrayResponse(BaseResponse):
+    response: typing.List["SecureSetCounterItem"]
+
+
+class SetCounterIntegerResponse(BaseResponse):
+    response: int
 
 
 for item in locals().copy().values():
