@@ -1,15 +1,17 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import StorageValue
 
+from .base_response import BaseResponse
+
 
 class GetKeysResponse(BaseResponse):
-    response: typing.List[str] = None
+    response: typing.List[str]
 
 
 class GetResponse(BaseResponse):
-    response: typing.List["StorageValue"] = None
+    response: typing.List["StorageValue"]
 
 
 for item in locals().copy().values():
