@@ -1,19 +1,21 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import BaseSticker, StoreProduct, StoreStickersKeyword
 
+from .base_response import BaseResponse
+
 
 class GetFavoriteStickersResponse(BaseResponse):
-    response: typing.List["BaseSticker"] = None
+    response: typing.List["BaseSticker"]
 
 
 class GetProductsResponse(BaseResponse):
-    response: typing.List["StoreProduct"] = None
+    response: typing.List["StoreProduct"]
 
 
 class GetStickersKeywordsResponse(BaseResponse):
-    response: "GetStickersKeywordsResponseModel" = None
+    response: "GetStickersKeywordsResponseModel"
 
 
 class GetStickersKeywordsResponseModel(BaseResponse):
