@@ -1,15 +1,17 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import WidgetsWidgetComment, WidgetsWidgetPage
 
+from .base_response import BaseResponse
+
 
 class GetCommentsResponse(BaseResponse):
-    response: "GetCommentsResponseModel" = None
+    response: "GetCommentsResponseModel"
 
 
 class GetPagesResponse(BaseResponse):
-    response: "GetPagesResponseModel" = None
+    response: "GetPagesResponseModel"
 
 
 class GetCommentsResponseModel(BaseResponse):
